# EDA-App

Below packages needed to run the plugin

```
pip install pandas-profiling==3.6.6 -t "/packages/custom_plugin/data_quality";
pip install bs4==0.0.1 -t "/packages/custom_plugin/data_quality";
pip install refractio[all]==2.0.5.9 -t "/packages/custom_plugin/data_quality";
```